@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 
-from mypy.execute import *
-from mypy.mylexer import MyLexer
-from mypy.mypy_errors import Error,ParseError
+from .execute import *
+from .mylexer import MyLexer
+from .mypy_errors import Error,ParseError
 
-if __name__ == '__main__':
+def main():
     lexer = MyLexer()
     parser = MyParser()
     env = {}
@@ -27,3 +27,8 @@ if __name__ == '__main__':
             except:
                 print("erreur innatendue")
                 continue
+
+
+if __name__ == "__main__":
+    main()
+
